@@ -106,6 +106,9 @@ DYNFUNC(return, const char *,          sqlite3_errmsg,                (sqlite3 *
 DYNFUNC(return, const char *,          sqlite3_errstr,                (int rc), (rc));
 #endif
 DYNFUNC(return, int,                   sqlite3_exec,                  (sqlite3 *db, const char *sql, sqlite3_callback c, void *v, char **errmsg), (db, sql, c, v, errmsg));
+#if SQLITE_VERSION_NUMBER >= 3014000
+DYNFUNC(return, char *,                sqlite3_expanded_sql,          (sqlite3_stmt *pStmt), (pStmt));
+#endif
 // DYNFUNC(return, int,                   sqlite3_expired,               (sqlite3_stmt *pStmt), (pStmt));
 DYNFUNC(return, int,                   sqlite3_extended_result_codes, (sqlite3 *db, int onoff), (db, onoff));
 DYNFUNC(return, int,                   sqlite3_finalize,              (sqlite3_stmt *pStmt), (pStmt));
@@ -183,6 +186,9 @@ DYNFUNC(return, int,                   sqlite3_stmt_readonly,         (sqlite3_s
 #if SQLITE_VERSION_NUMBER >= 3007000
 DYNFUNC(return, int,                   sqlite3_stmt_status,           (sqlite3_stmt* pStmt, int op, int resetFlg), (pStmt, op, resetFlg));
 #endif
+#if SQLITE_VERSION_NUMBER >= 3012001
+DYNFUNC(return, int,                   sqlite3_system_errno,          (sqlite3* db), (db));
+#endif
 DYNFUNC(return, int,                   sqlite3_threadsafe,            (void), ());
 // DYNFUNC(return, int,                   sqlite3_total_changes,         (sqlite3 *db), (db));
 // DYNFUNC(return, void *,                sqlite3_trace,                 (sqlite3 *db, void(*xTrace)(void*,const char*), void *pArg), (db, xTrace, pArg));
